@@ -38,6 +38,13 @@
 
 #define CA_PRINTF_BUFFER_SIZE	1024	/* see: os_printf */
 
+/*---------------------------------------------------------------------------*\
+\*---------------------------------------------------------------------------*/
+static unsigned long long       j64 = 0;
+static unsigned long            j32 = 0;
+
+#define JIFF2MSEC               (1000/HZ)
+
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
 void os__enter_critical (const char * f, int l) { 
@@ -80,7 +87,7 @@ char * os_params (void) {
 \*---------------------------------------------------------------------------*/
 int os_get_message (unsigned char * msg) {
 
-	assert (msg);
+	assert (msg != NULL);
 	return msg2stack (msg); 
 } /* os_get_message */
 
@@ -88,7 +95,7 @@ int os_get_message (unsigned char * msg) {
 \*---------------------------------------------------------------------------*/
 void os_put_message (unsigned char * msg) {
 
-	assert (msg);
+	assert (msg != NULL);
 	msg2capi (msg);
 } /* os_put_message */
 
@@ -208,15 +215,42 @@ void os_free (void * p) {
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
-unsigned long os_msec (void) {
-	static int		init = 0;
-	static unsigned long	jbuf;
+static void update_j64 (void) {
+	static int	run1 = 1;
+	unsigned long	j;
+	long long	diff;
 
-	if (!init || (jiffies < jbuf)) {
-		jbuf = jiffies;
-		init = 1;
+	j = jiffies;
+	if (run1) {
+		j32 = j;
+		run1 = 0;
 	}
-	return ((jiffies - jbuf) * 1000) / HZ;
+	if ((diff = j - j32) < 0) {
+		diff = -diff;
+	}
+	assert (diff >= 0);
+	j32 = j;
+	j64 += diff;
+} /* update_j64 */
+
+/*---------------------------------------------------------------------------*\
+\*---------------------------------------------------------------------------*/
+unsigned long long os_msec64 (void) {
+	unsigned long   tmp;
+
+	update_j64 ();
+	tmp = j64 * JIFF2MSEC;
+	return tmp;
+} /* os_msec64 */
+
+/*---------------------------------------------------------------------------*\
+\*---------------------------------------------------------------------------*/
+unsigned long os_msec (void) {
+	unsigned long   tmp;
+
+	update_j64 ();
+	tmp = ((unsigned long) j64) * JIFF2MSEC;
+	return tmp;
 } /* os_msec */
 
 /*---------------------------------------------------------------------------*\
@@ -266,7 +300,6 @@ int os_timer_start (
 	unsigned long	arg,
 	timerfunc_t	func
 ) {
-
 	assert (index < timer_count);
 	if (index >= timer_count) {
 		return 1;
@@ -339,18 +372,18 @@ void os_printf (char * s, va_list args) {
 		printk ("\n");
 	}	
 	count = VSNPRINTF (bufptr, sizeof (buffer), s, args);
-	va_end (args);
 	if ('\n' == buffer[0]) {
 		bufptr++;
 	}
 	if ('\n' != buffer[count - 1]) {
-		assert (count < 498);
+		assert (count < (CA_PRINTF_BUFFER_SIZE - 4));
 		buffer[count++] = '\n';
 		buffer[count]   = (char) 0;
 	}
 	lprintf (KERN_INFO, bufptr);
 #else
 	s = s;
+	args = args;
 #endif
 } /* os_printf */
 
