@@ -30,11 +30,11 @@
 #include "tools.h"
 
 typedef struct __header {
-    unsigned		type;
+	unsigned		type;
 #if !defined (NDEBUG)
-    unsigned		size;
-    unsigned		from;
-    unsigned		tag;
+	unsigned		size;
+	unsigned		from;
+	unsigned		tag;
 #endif
 } header_t;
 
@@ -129,7 +129,7 @@ static void * halloc (unsigned size, unsigned addr) {
 		mem = (void *) (hdr + 1);
 		hdr->type = t;
 #if !defined (NDEBUG)
-#if defined (LOG_MEM_BLOCKS)
+#if defined (LOG_ALLOC)
 		printk (KERN_INFO "ALLOC %6u bytes @ %08X\n", size, addr);
 #endif
 		hdr->size = size ? size : 1;
@@ -174,7 +174,7 @@ void hfree (void * mem) {
 	if (mem != NULL) {
 		hdr = ((header_t *) mem) - 1;
 #if !defined (NDEBUG)
-#if defined (LOG_MEM_BLOCKS)
+#if defined (LOG_ALLOC)
 		printk (KERN_INFO "FREE  %6u bytes @ %08X\n", hdr->size, hdr->from);
 #endif
 		fence1 = (hdr->tag == FENCE_TAG);
@@ -291,7 +291,6 @@ void timers_stop (void) {
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
-
 void vlprintf (const char * level, const char * fmt, va_list args) {
 	static char	line[1024];
 
@@ -336,11 +335,3 @@ void _OSinfo (void * exp, void * file, unsigned line) {
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
 
-unsigned long atomic_xchg (volatile atomic_t * v, unsigned value) {
-
-	return __xchg (value, &v->counter, sizeof (unsigned));
-} /* atomic_xchg */
-
-/*---------------------------------------------------------------------------*\
-\*---------------------------------------------------------------------------*/
-
